@@ -735,7 +735,7 @@
                 iface = "wlan0";
                 break;
             default:
-                iface = registry.getValue("network.tcp.eth1.mac") ? "eth1" : "eth0";
+                iface = registry.getValue("network.eth1.tcp.mac") ? "eth1" : "eth0";
                 break;
             }
 
